The HTTP `TRACE` method is normally not required within production
sites and should therefore be disabled.

Depending on the function being performed by the web application,
the risk level can start low and increase as more functionality
is implemented.

The remediation is typically a very simple configuration change
and in most cases will not have any negative impact on the server
or application.